"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Command = void 0;
const url_1 = require("url");
const ContentstackDeliverySDK = require("contentstack");
const cli_utilities_1 = require("@contentstack/cli-utilities");
const defaultRateLimit = 5;
class ContentstackCommand extends cli_utilities_1.Command {
    get context() {
        // @ts-ignore
        return this.config.context || {};
    }
    get email() {
        if (this._email)
            return this._email;
        this._email = cli_utilities_1.configHandler.get('email');
        if (this._email)
            return this._email;
        throw new cli_utilities_1.CLIError('You are not logged in. Please login with command $ csdx auth:login');
    }
    get deliveryAPIClient() {
        if (this._deliveryAPIClient)
            return this._deliveryAPIClient;
        this._deliveryAPIClient = ContentstackDeliverySDK;
        return this._deliveryAPIClient;
    }
    get region() {
        if (!this._region)
            this._region = cli_utilities_1.configHandler.get('region');
        if (!this._region) {
            cli_utilities_1.cliux.print('Error: Region not configured. Please set the region.', { color: 'red' });
            process.exit(1);
        }
        return this._region;
    }
    get rateLimit() {
        this._rateLimit = cli_utilities_1.configHandler.get('rate-limit');
        if (this._rateLimit)
            return this._rateLimit;
        return defaultRateLimit;
    }
    get cmaHost() {
        let cma = this.region.cma;
        if (cma.startsWith('http')) {
            const u = new url_1.URL(cma);
            if (u.host)
                return u.host;
        }
        return cma;
    }
    get cdaHost() {
        let cda = this.region.cda;
        if (cda.startsWith('http')) {
            const u = new url_1.URL(cda);
            if (u.host)
                return u.host;
        }
        return cda;
    }
    get uiHost() {
        return this.region.uiHost;
    }
    get cdaAPIUrl() {
        let cda = this.region.cda;
        return cda.startsWith('http') ? cda : `https://${cda}`;
    }
    get cmaAPIUrl() {
        let cma = this.region.cma;
        return cma.startsWith('http') ? cma : `https://${cma}`;
    }
    getToken(alias) {
        if (alias) {
            const token = cli_utilities_1.configHandler.get(`tokens.${alias}`);
            if (token)
                return token;
        }
        throw new cli_utilities_1.CLIError('No token found');
    }
}
exports.Command = ContentstackCommand;
module.exports = {
    Command: ContentstackCommand,
};
